%define upstream_name    Data-Entropy
%define upstream_version 0.008

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Download entropy from
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Data/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Crypt::Rijndael)
BuildRequires: perl(Crypt::URandom) >= 0.360.0
BuildRequires: perl(Data::Float) >= 0.8.0
BuildRequires: perl(Errno) >= 1.0.0
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(HTTP::Lite) >= 2.200.0
BuildRequires: perl(IO::File) >= 1.30.0
BuildRequires: perl(Module::Build)
BuildRequires: perl(Params::Classify)
BuildRequires: perl(Test::More)
BuildRequires: perl(constant)
BuildRequires: perl(integer)
BuildRequires: perl(parent)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
This module maintains a concept of a current selection of entropy source.
Algorithms that require entropy, such as those in the
Data::Entropy::Algorithms manpage, can use the source nominated by this
module, avoiding the need for entropy source objects to be explicitly
passed around. This is convenient because usually one entropy source will
be used for an entire program run and so an explicit entropy source
parameter would rarely vary. There is also a default entropy source,
avoiding the need to explicitly configure a source at all.

If nothing is done to set a source then it defaults to the use of Rijndael
(AES) in counter mode (see the Data::Entropy::RawSource::CryptCounter
manpage and the Crypt::Rijndael manpage), keyed using Perl's built-in
'rand' function. This gives a data stream that looks like concentrated
entropy, but really only has at most the entropy of the 'rand' seed. Within
a single run it is cryptographically difficult to detect the correlation
between parts of the pseudo-entropy stream. If more true entropy is
required then it is necessary to configure a different entropy source.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc Changes META.json META.yml MYMETA.yml README SIGNATURE
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Mon Jul 07 2025 umeabot <umeabot> 0.8.0-2.mga10
+ Revision: 2250281
- Mageia 10 Mass Rebuild

* Sun Mar 30 2025 tv <tv> 0.8.0-1.mga10
+ Revision: 2171668
- update to 0.008

* Sun Mar 20 2022 umeabot <umeabot> 0.7.0-10.mga9
+ Revision: 1802785
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.7.0-9.mga8
+ Revision: 1493646
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 0.7.0-8.mga7
+ Revision: 1266838
- Mageia 7 Mass Rebuild

* Sat Jun 18 2016 pterjan <pterjan> 0.7.0-7.mga6
+ Revision: 1024802
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 0.7.0-6.mga6
+ Revision: 943528
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-5.mga5
+ Revision: 743597
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-4.mga5
+ Revision: 684199
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.7.0-3.mga4
+ Revision: 510582
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.7.0-2.mga3
+ Revision: 365317
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jun 15 2011 jquelin <jquelin> 0.7.0-1.mga2
+ Revision: 107843
- update to 0.007

* Tue Jan 25 2011 jquelin <jquelin> 0.6.0-1.mga1
+ Revision: 38588
- mageia rebuild
- imported package perl-Data-Entropy

